@@ -23,7 +23,7 @@
 #include "cddb.h"
 
 static GHashTable *cddb_cache;
-static CDDBSlaveClient *slave = NULL;
+static CDDBSlaveClient *slave_client = NULL;
 void freekey(gpointer key, gpointer value,gpointer userdata);
 static int
 count_tracks (CDDBSlaveClientTrackInfo **info)
@@ -52,14 +52,16 @@ get_disc_info (GnomeCD *gcd,
 		gcd->disc_info = info;
 	}
 
-	info->artist = cddb_slave_client_get_artist (slave, discid);
-	info->title = cddb_slave_client_get_disc_title (slave, discid);
-	info->track_info = cddb_slave_client_get_tracks (slave, discid);
-        gcd_debug ("get_disc_info: artist %s, title %s", info->artist, info->title);
+	info->artist = cddb_slave_client_get_artist (slave_client, discid);
+	info->title = cddb_slave_client_get_disc_title (slave_client, discid);
+	info->track_info = cddb_slave_client_get_tracks (slave_client, discid);
+        gcd_debug ("get_disc_info: artist %s, title %s, track_info %p",
+		info->artist, info->title, info->track_info);
 
 	if (count_tracks (info->track_info) != info->ntracks) {
 		/* Duff info */
 		cddb_slave_client_free_track_info (info->track_info);
+		gcd_debug ("Track count doesn't match, bad entry ?");
 		info->track_info = NULL;
 		gcd->disc_info = NULL;
 	}
@@ -78,6 +80,18 @@ cddb_listener_event_cb (BonoboListener *listener,
 
 	qr = arg->_value;
 
+	gcd_debug ("Got a result for discid %s on listener %p", qr->discid, listener);
+	if (gcd->discid == NULL) {
+		/* We weren't looking up, so just return */
+		gcd_debug ("We're not looking up, so ignoring");
+		return;
+	}
+	if (strcmp (gcd->discid, qr->discid) != 0) {
+		gcd_debug ("Not our discid, so ignoring");
+		return;
+	}
+	g_free (gcd->discid);
+	gcd->discid = NULL;
 	switch (qr->result) {
 	case GNOME_Media_CDDBSlave2_OK:
 		get_disc_info (gcd, qr->discid);
@@ -143,9 +157,10 @@ cddb_make_disc_info (GnomeCDRomCDDBData *data)
 void
 cddb_close_client (void)
 {
-	if (slave != NULL)
-		g_object_unref (G_OBJECT (slave));
+	if (slave_client != NULL)
+		g_object_unref (G_OBJECT (slave_client));
 }
+
 // when the CD is ejected we need to destroy the cddb_cache hashTable
 void destroy_cache_hashTable()
 {
@@ -215,16 +230,21 @@ cddb_get_query (GnomeCD *gcd)
 	/* Remove the last space */
 	offsets[strlen (offsets) - 1] = 0;
 
-	if (slave == NULL) {
-		slave = cddb_slave_client_new ();
+	/* Create a new slave client if we don't have one yet */
+	if (slave_client == NULL) {
+		slave_client = cddb_slave_client_new ();
 		listener = bonobo_listener_new (NULL, NULL);
+		gcd_debug ("Created a new bonobo listener %p", listener);
 		g_signal_connect (G_OBJECT (listener), "event-notify",
 				  G_CALLBACK (cddb_listener_event_cb), gcd);
 
-		cddb_slave_client_add_listener (slave, listener);
+		cddb_slave_client_add_listener (slave_client, listener);
 	}
 
-	cddb_slave_client_query (slave, discid, data->ntrks, offsets, 
+	gcd_debug ("Performing lookup for:");
+	gcd_debug ("%s %d %s %d", discid, data->ntrks, offsets, data->nsecs);
+	gcd->discid = discid;
+	cddb_slave_client_query (slave_client, discid, data->ntrks, offsets, 
 				 data->nsecs, "GnomeCD", VERSION);
 	
 	gnome_cdrom_free_cddb_data (data);
