@@ -619,10 +619,10 @@ file_mixer (BonoboUIComponent *uic,
 	gboolean ret;
 
 	/* Open the mixer */
-	mixer_path = g_find_program_in_path ("gst-mixer");
+	mixer_path = g_find_program_in_path ("gnome-volume-control");
 	if (mixer_path == NULL) {
 		char *tmp;
-		tmp = g_strdup_printf(_("%s is not installed in the path."), "gst-mixer");
+		tmp = g_strdup_printf(_("%s is not installed in the path."), "gnome-volume-control");
 		show_error_dialog (GTK_WINDOW (window), tmp);
 		g_free(tmp);
 		return;
@@ -951,6 +951,7 @@ help_about (BonoboUIComponent *uic,
 	static GtkWidget *about = NULL;
 	GdkPixbuf *pixbuf = NULL;
 	const char *authors[2] = {"Iain Holmes <iain@prettypeople.org>", NULL};
+	const char *documentors[2] = {"Sun Microsystems", NULL};
 
 	if (about != NULL) {
 		gdk_window_raise (about->window);
@@ -960,7 +961,7 @@ help_about (BonoboUIComponent *uic,
 		about = gnome_about_new (_("Sound Recorder"), VERSION,
 					 "Copyright \xc2\xa9 2002 Iain Holmes",
 					 _("A sound recorder for GNOME"),
-					 authors, NULL, NULL, pixbuf);
+					 authors, documentors, NULL, pixbuf);
 
 		if (pixbuf != NULL)
 			gdk_pixbuf_unref (pixbuf);
@@ -1022,10 +1023,13 @@ media_record (BonoboUIComponent *uic,
 {
 	GSRWindowPrivate *priv = window->priv;
 
+	if (priv->record) {
+		gst_element_set_state (priv->record->pipeline, GST_STATE_NULL);
+		g_object_unref (priv->record->pipeline);
+	}
 	priv->record = make_record_pipeline (window);
 
 	if (priv->record != NULL) {
-		g_print ("setting location to %s\n", priv->record_filename);
 		g_object_set (G_OBJECT (priv->record->sink),
 			      "location", priv->record_filename,
 			      NULL);
@@ -1381,10 +1385,6 @@ record_state_changed_cb (GstElement *element,
 			 GstElementState state,
 			 GSRWindow *window)
 {
-	g_print ("%s: entered: %s->%s\n", __FUNCTION__,
-		 gst_element_state_get_name (old),
-		 gst_element_state_get_name (state));
-	
 	switch (state) {
 	case GST_STATE_PLAYING:
 		window->priv->record_id = g_idle_add (record_start, window);
@@ -1435,7 +1435,6 @@ make_record_pipeline (GSRWindow *window)
 					 gst_gconf_get_string ("default/audiosrc"),
 					 gm_audio_profile_get_pipeline (profile));
 	
-	g_print ("Creating pipeline: %s\n", pipeline_desc);
 	encoder = gst_gconf_render_bin_from_description (pipeline_desc);
 	g_free (pipeline_desc);
 	if (!encoder) {
